@@ -2,6 +2,7 @@ from .exceptions import ConnectionClosed
 
 import websockets.client
 import websockets.exceptions
+import socket
 import asyncio
 import json
 
@@ -15,6 +16,9 @@ class Connection():
         try:
             self._conn = await websockets.client.connect(url, close_timeout=0, max_size=None)
 
+        except socket.gaierror:
+            raise ConnectionClosed("Hostname cannot be resolved")
+
         except asyncio.exceptions.TimeoutError:
             raise ConnectionClosed("Connection timed out")
 
